import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class CountLastPatternMatchesResult(ResultBase):
    def __init__(self, json1, successMessage, errorMessage):
        jsonObj = json.loads(json1)
        ResultBase.__init__(self, jsonObj["matches"] != -1 and jsonObj["errorCode"] == 0, successMessage, errorMessage)

        self.matches = jsonObj["matches"]

        if(self.success):
            return

        if("errorCode" in jsonObj):
            self.message = self.getMessageForErrorCode(self.message, jsonObj["errorCode"])


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class SaveFileResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        if("saved" in jsonObj):
            jsonObj["ok"] = jsonObj["saved"]
        self.filePath = jsonObj["generatedFilename"]
        ResultBase.__init__(self, True if jsonObj["ok"] else False, successMessage, failMessage)

        if(self.success):
            return

        if("errorCode" in jsonObj):
            self.message = self.getMessageForErrorCode(self.message, jsonObj["errorCode"])
        else:
            self.message = self.message + jsonObj["errorMessage"]


import sys
import json

from testwizard.commands_core import CommandBase
from .GetVideoFormatResult import GetVideoFormatResult

class GetVideoFormatCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "GetVideoFormat")

    def execute(self):
        requestObj = []
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return GetVideoFormatResult(response.read(), "v was successful", "GetVideoFormat failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForPatternResult import WaitForPatternResult

class WaitForPatternCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "WaitForPattern")
    
    def execute(self, filename, minSimilarity, timeout, mode, x, y, width, height):
        if(filename == None):
            raise Exception("filename is required")
        if(minSimilarity == None):
            raise Exception("minSimilarity is required")
        if(timeout == None):
            raise Exception("timeout is required")
        if(mode == None):
            raise Exception("mode is required")
        if(x == None):
            raise Exception("x is required")
        if(y == None):
            raise Exception("y is required")
        if(width == None):
            raise Exception("width is required")
        if(height == None):
            raise Exception("height is required")

        requestObj = [filename, minSimilarity, timeout, mode, x, y, width, height]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return WaitForPatternResult(response.read(), "WaitForPattern was successful", "WaitForPattern failed")


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class GetVideoResolutionResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        self.width = jsonObj["width"]
        self.height = jsonObj["height"]
        ResultBase.__init__(self, False if self.width==-1 or self.height==-1 else True, successMessage, failMessage)


import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult

class FilterGrayscaleCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "FilterGrayscale")
    
    def execute(self, levels):

        if(levels==None):
            raise Exception("levels is required")
        
        requestObj = [levels]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return FilterResult(response.read(), "FilterGrayscale was successful", "FilterGrayscale failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .GetVideoResolutionResult import GetVideoResolutionResult

class GetVideoResolutionCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "GetVideoResolution")
    
    def execute(self):
        requestObj = []
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return GetVideoResolutionResult(response.read(), "GetVideoResolution was successful", "GetVideoResolution failed")


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class FindPatternResult(ResultBase):
    def __init__(self, json1, successMessage, failMessage):
        jsonObj = json.loads(json1)
        self.similarity = jsonObj["similarity"]
        self.position = jsonObj["position"]
        ResultBase.__init__(self, True if self.similarity!= -1 and jsonObj["errorCode"] == 0 else False, successMessage, failMessage)

        if(self.success):
            return

        if("errorCode" in jsonObj):
            self.message = self.getMessageForErrorCode(self.message, jsonObj["errorCode"])


import sys
import json

from testwizard.commands_core import CommandBase
from .SaveFileResult import SaveFileResult

class SnapShotJPGCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "SnapShotJPG")
    
    def execute(self, filename, quality):
        if(filename==None):
            raise Exception("filename is required")
        if(quality==None):
            raise Exception("quality is required")

        requestObj = [filename, quality]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return SaveFileResult(response.read(), "SnapShotJPG was successful", "SnapShotJPG failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .CompareResult import CompareResult

class CompareCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "Compare")
    
    def execute(self, x, y, width, height, filename, tolerance):
        
        if(x==None):
            raise Exception("x is required")
        if(y==None):
            raise Exception("y is required")
        if(width==None):
            raise Exception("width is required")
        if(height==None):
            raise Exception("height is required")
        if(filename==None):
            raise Exception("filename is required")
        if(tolerance==None):
            raise Exception("tolerance is required")

        requestObj = [x, y, width, height, filename, tolerance]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return CompareResult(response.read(),"compare was successful", "compare failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .TextOCRResult import TextOCRResult

class TextOCRCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "TextOCR")

    def execute(self, dictionary):
        if(dictionary==None):
            raise Exception("dictionary is required")

        requestObj = [dictionary]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return TextOCRResult(response.read(), "TextOCR was successful", "TextOCR failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult

class FilterBlackWhiteCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "FilterBlackWhite")
    
    def execute(self, separation):
        
        if(separation==None):
            raise Exception("separation is required")

        requestObj = [separation]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")
        
        return FilterResult(response.read(), "FilterBlackWhite was successful", "FilterBlackWhite failed")   


import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult

class SetRegionCommand(CommandBase):
    def __init__(self, session, testObjectName):
        CommandBase.__init__(self, session, testObjectName, "SetRegion")

    def execute(self, x, y, width, height):
        if(x==None):
            raise Exception("x is required")
        if(y==None):
            raise Exception("y is required")
        if(width==None):
            raise Exception("width is required")
        if(height==None):
            raise Exception("height is required")

        requestObj = [x, y, width, height]
        requestObj = json.dumps(requestObj)

        response = self.robot.post(self.url, requestObj, "Could not execute command")

        return FilterResult(response.read(), "SetRegion was successful", "SetRegion failed")